fix_omp_conflict: Fix OpenMP linking issue

View source: R/fixes.R

fix_omp_conflictR Documentation

Fix ⁠OpenMP⁠ linking issue

Description

Fix ⁠OpenMP⁠ linking issue

Usage

fix_omp_conflict(env_name = NA)

Arguments

env_name

environment name, see env_path.

Details

On ⁠MacOS⁠, R framework and ⁠conda⁠ each ship their own ⁠libomp.dylib⁠. When both are loaded in the same process, the run-time raises error because different copies of ⁠OpenMP⁠ are initialized. To solve this issue, a symbolic link to R's framework copy ensures dynamical loading resolves both to the same canonical path and initializes the run-time exactly once.

Value

Whether the symbolic link is created.

Examples


## Not run: 

fix_omp_conflict()


## End(Not run)


rpymat documentation built on May 23, 2026, 9:11 a.m.