repl_python: Enable interactive 'python' from R

repl_pythonR Documentation

Enable interactive 'python' from R

Description

Allows users to type 'python' command from R console for quick code evaluation or debugging.

Usage

repl_python(..., env_name = NA)

Arguments

...

passed to repl_python in 'reticulate' package

env_name

environment name to activate, if not default. This argument is ignored if any other environment is activated; see ensure_rpymat.

Value

See repl_python


rpymat documentation built on May 23, 2026, 9:11 a.m.