| fix_omp_conflict | R Documentation |
OpenMP linking issueFix OpenMP linking issue
fix_omp_conflict(env_name = NA)
env_name |
environment name, see |
On MacOS, R framework and conda each ship their own
libomp.dylib. When both are loaded in the same process, the
run-time raises error because different copies of OpenMP
are initialized. To solve this issue, a symbolic link to R's framework copy
ensures dynamical loading resolves both to the same canonical path and
initializes the run-time exactly once.
Whether the symbolic link is created.
## Not run:
fix_omp_conflict()
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.